Gaphor - The UML and SysML(soon!) Modeling Tool
========================================

Gaphor is a free/libre/open source UML modeling tool, written in Python and licensed under the GPLv2.

Install gaphor simply using pip:

  $ pip install gaphor

You can find the sources and issue tracker at GitLab:

  http://gitlab.com/MBSE/gaphor/

For documentation refer to our project website:

  http://mbse.gitlab.io/gaphor/